@@ -28,6 +28,14 @@
 #include "ping.h"
 #include "utils.h"
 
+enum {
+	BYTES_COLUMN = 0,
+	IP_COLUMN,
+	ICMP_SEQ_COLUMN,
+	SRTT_COLUMN,
+	UNIT_COLUMN,
+};
+
 static gint strip_line (gchar * line, ping_data * data, Netinfo * netinfo);
 static gint strip_total_line (gchar * line, gint * packet_total);
 static GtkTreeModel *ping_create_model (GtkTreeView * widget);
@@ -35,7 +43,178 @@ static GtkTreeModel *ping_create_model (GtkTreeView * widget);
 static gfloat rttmin, rttmax, rttavg;
 static gint packets_transmitted;
 static gint packets_received;
-static gint packets_loss;
+static gint packets_success;
+
+typedef struct {
+	gdouble value;
+	gboolean valid;
+} PingGraphBarData;
+
+static void
+draw_centered_text (GtkWidget *widget, cairo_t *cr, gint x, gint y, gchar *text)
+{
+	int width;
+	PangoLayout *layout;
+
+	layout = gtk_widget_create_pango_layout (widget, text);
+
+	pango_layout_get_pixel_size (layout, &width, NULL);
+
+	x -= width/2;
+
+	gtk_paint_layout (gtk_widget_get_style(widget), cr,
+			  GTK_STATE_NORMAL, TRUE, 
+			  widget, NULL, x, y,
+			  layout);
+	g_object_unref (layout);
+}
+
+static gdouble 
+get_bar_data (Netinfo *netinfo, PingGraphBarData *bar_data, int ntodisplay,
+	      gint rangemin, gint rangemax)
+{
+	gint i, index;
+	GtkTreeModel *results;
+	GtkTreeIter node;
+	gboolean nodeavailable;
+	gint seqnumber;
+	gchar *srtt_str;
+	gdouble max;
+
+	for (i = 0; i<ntodisplay; i++) {
+		bar_data[i].value = 0;
+		bar_data[i].valid = FALSE;
+	}
+	
+	results = gtk_tree_view_get_model (GTK_TREE_VIEW (netinfo->output));
+
+	if (results != NULL) {
+		nodeavailable = gtk_tree_model_get_iter_first (results, &node);
+		while (nodeavailable) {
+			gtk_tree_model_get (results, &node, 
+					    ICMP_SEQ_COLUMN, &seqnumber, -1);
+			index = seqnumber - rangemin - 1;
+			if (seqnumber > rangemin) {
+				gtk_tree_model_get (results, &node, 
+						    SRTT_COLUMN, &srtt_str, 
+						    -1);
+				bar_data[index].value = g_strtod (srtt_str, 
+								  NULL);
+				g_free (srtt_str);
+				bar_data[index].valid = TRUE;
+			}
+			nodeavailable = gtk_tree_model_iter_next (results, &node);
+		}
+
+	}
+
+	max = 0.0;
+	for (i = 0; i<ntodisplay; i++)
+		if (bar_data[i].valid && (bar_data[i].value > max))
+			max = bar_data[i].value;
+
+	return max;
+}
+
+static void 
+draw_ping_graph (Netinfo *netinfo)
+{
+	cairo_t *cr;
+	GtkStyle *style;
+	GtkWidget *widget;
+	PangoLayout *layout;
+	gint ntodisplay = 5;
+	gint rangemin, rangemax;
+	PingGraphBarData *bar_data;
+	gdouble max;
+	gint width, height;
+	gint font_height, offset;
+	gint bar_height, separator_height;
+	gdouble scale_factor;
+	gint line1h, line2h;
+	gint index;
+	gint step, x, h;
+	gchar *tmpstr;
+
+	widget = netinfo->graph;
+	cr = gdk_cairo_create (gtk_widget_get_window(widget));
+	style = gtk_widget_get_style(widget);
+
+	rangemax = packets_transmitted;
+	rangemin = MAX (0, rangemax - ntodisplay);
+
+	bar_data = g_newa (PingGraphBarData, ntodisplay);
+	max = get_bar_data (netinfo, bar_data, ntodisplay, rangemin,
+			    rangemax);
+
+	/* Created up here so we can get the geometry info. */
+	layout = gtk_widget_create_pango_layout (widget, _("Time (ms):"));
+	/* We guess that the first label is representative. */
+	pango_layout_get_pixel_size (layout, NULL, &font_height);
+	width = gtk_widget_get_allocated_width (widget);
+	height = gtk_widget_get_allocated_height (widget);
+
+	offset = 0.05*height;
+	bar_height = height - 2.5*font_height - offset;
+	scale_factor = bar_height / max;
+	separator_height = bar_height + offset;
+	line1h = bar_height + 0.125*font_height + offset;
+	line2h = bar_height + 1.25*font_height + offset;
+
+	gtk_paint_box (style, cr, GTK_STATE_NORMAL, GTK_SHADOW_ETCHED_IN, 
+		       widget, NULL, 0, 0, width, height);
+
+	gtk_paint_layout (style, cr, GTK_STATE_NORMAL, TRUE, 
+			  widget, NULL, 0.02*width, line1h,
+			  layout);
+	g_object_unref (layout);
+
+	layout = gtk_widget_create_pango_layout (widget, _("Seq. No.:"));
+	gtk_paint_layout (style, cr, GTK_STATE_NORMAL, TRUE, 
+			  widget, NULL, 0.02*width, line2h,
+			  layout);
+	g_object_unref (layout);
+
+	gtk_paint_hline (style, cr, GTK_STATE_NORMAL, widget, NULL,
+			 0.02*width, 0.98*width, separator_height);
+
+	index = 0;
+	step = width / (ntodisplay + 1.0);
+	for (x = 1.5*step; x < width; x += step) {
+		if (bar_data[index].valid) {
+			h = scale_factor*bar_data[index].value;
+			gtk_paint_flat_box (style, cr, GTK_STATE_SELECTED,
+					    GTK_SHADOW_ETCHED_IN, widget,
+					    NULL, x - 0.4*step,
+					    offset + bar_height - h,
+					    0.8*step, h);
+			tmpstr = g_strdup_printf ("%.2f", bar_data[index].value);
+		} else {
+			tmpstr = g_strdup ("-");
+		}
+		draw_centered_text (widget, cr, x, line1h, tmpstr);
+		g_free (tmpstr);
+		if (index + rangemin + 1 <= rangemax) {
+			tmpstr = g_strdup_printf ("%d", index + rangemin + 1);
+		} else {
+			tmpstr = g_strdup ("-");
+		}
+		draw_centered_text (widget, cr, x, line2h, tmpstr);
+		g_free (tmpstr);
+		index++;
+	}
+
+	cairo_destroy (cr);
+}
+
+gint 
+on_ping_graph_draw (GtkWidget *widget, cairo_t *cr,
+		      Netinfo *info)
+{
+	draw_ping_graph (info);
+
+	return TRUE;
+}
 
 void
 ping_stop (Netinfo * netinfo)
@@ -48,14 +227,15 @@ ping_stop (Netinfo * netinfo)
 void
 ping_do (Netinfo * netinfo)
 {
-	gushort count;
+	gint count;
 	const gchar *host = NULL;
 	gchar *command = NULL;
 	GtkTreeModel *model;
 	GtkLabel *min, *avg, *max, *pkt_transmitted, *pkt_received,
-	    *pkt_loss;
+	    *pkt_success;
 	gchar stmp[128];
 	gchar *program = NULL;
+	gchar *count_string = NULL;
 	GtkWidget *parent;
 	gint ip_version;
 
@@ -77,7 +257,7 @@ ping_do (Netinfo * netinfo)
 	netinfo->stbar_text = g_strdup_printf (_("Sending ping requests to %s"), host);
 	
 	rttmin = rttavg = rttmax = 0.0;
-	packets_transmitted = packets_received = packets_loss = 0;
+	packets_transmitted = packets_received = packets_success = 0;
 
 	/* Clear the statistics before starting a ping */
 
@@ -93,25 +273,21 @@ ping_do (Netinfo * netinfo)
 
 	pkt_transmitted = GTK_LABEL (netinfo->packets_transmitted);
 	pkt_received = GTK_LABEL (netinfo->packets_received);
-	pkt_loss = GTK_LABEL (netinfo->packets_loss);
+	pkt_success = GTK_LABEL (netinfo->packets_success);
 	g_sprintf (stmp, "%d", packets_transmitted);
 	gtk_label_set_text (pkt_transmitted, stmp);
 	g_sprintf (stmp, "%d", packets_received);
 	gtk_label_set_text (pkt_received, stmp);
-	g_sprintf (stmp, "%d%%", packets_loss);
-	gtk_label_set_text (pkt_loss, stmp);
+	g_sprintf (stmp, "%d%%", packets_success);
+	gtk_label_set_text (pkt_success, stmp);
 
 	model = gtk_tree_view_get_model (GTK_TREE_VIEW (netinfo->output));
 	if (GTK_IS_LIST_STORE (model)) {
 		gtk_list_store_clear (GTK_LIST_STORE (model));
 	}
-/*
-	buffer =
-	    gtk_text_view_get_buffer (GTK_TEXT_VIEW (netinfo->output));
 
-	gtk_text_buffer_get_bounds (buffer, &start, &end);
-	gtk_text_buffer_delete (buffer, &start, &end);
-*/
+	draw_ping_graph (netinfo);
+
 	parent = gtk_widget_get_toplevel (netinfo->output);
 
 	ip_version = netinfo_get_ip_version (netinfo);
@@ -131,31 +307,37 @@ ping_do (Netinfo * netinfo)
 	}
 	
 	if (program != NULL) {
+		/* unlimited or limited ping? */
+		if (count == -1) {
+			count_string = g_strdup_printf(" ");
+		} else {
 #if defined(__sun__) || defined(__hpux__)
-		if (ip_version == IPV4)
-			command =
-				g_strdup_printf (PING_PROGRAM_FORMAT, program, host,
-	 //	    g_strdup_printf (PING_PROGRAM_FORMAT, PING_PROGRAM, host,	
-						 count);
-		else
-			command =
-				g_strdup_printf (PING_PROGRAM_FORMAT_6, program, host,
-						 count);
+			count_string = g_strdup_printf("%d", count);
 #else
-		if (ip_version == IPV4)
-			command =
-				g_strdup_printf (PING_PROGRAM_FORMAT, program, count,
-	//	    g_strdup_printf (PING_PROGRAM_FORMAT, PING_PROGRAM, count,
-						 host);
-		else
-			command =
-				g_strdup_printf (PING_PROGRAM_FORMAT_6, program, count,
-						 host);
+			count_string = g_strdup_printf(" -c %d ", count);
 #endif
+		}
 
-/*	command =
-	    g_strdup_printf ("%s ping -c %d %s", PING_PROGRAM, count,
-			     host);*/
+		if (ip_version == IPV4) {
+			command =
+#if defined(__sun__) || defined(__hpux__)
+				g_strdup_printf (PING_PROGRAM_FORMAT, program, 
+						host, count_string);
+#else
+				g_strdup_printf (PING_PROGRAM_FORMAT, program, 
+						count_string, host);
+#endif
+		} else {
+			command =
+#if defined(__sun__) || defined(__hpux__)
+				g_strdup_printf (PING_PROGRAM_FORMAT_6, program, 
+						host, count_string);
+#else
+				g_strdup_printf (PING_PROGRAM_FORMAT_6, program, 
+						count_string, host);
+#endif
+		}
+		g_print("command: %s\n", command);
 
 		netinfo->command_line = g_strsplit (command, " ", -1);
 	
@@ -164,6 +346,7 @@ ping_do (Netinfo * netinfo)
 		g_strfreev (netinfo->command_line);
 	}
 	
+	g_free (count_string);
 	g_free (command);
 	g_free (program);
 }
@@ -200,7 +383,7 @@ void
 ping_foreach_with_tree (Netinfo * netinfo, gchar * line, gint len,
 			gpointer user_data)
 {
-	GtkTreeIter iter, sibling;
+	GtkTreeIter iter;
 	GList *columns;
 	GtkTreePath *path;
 	GtkTreeModel *model;
@@ -209,7 +392,7 @@ ping_foreach_with_tree (Netinfo * netinfo, gchar * line, gint len,
 	ping_data data;
 	gdouble rtt;
 	GtkLabel *min, *avg, *max, *pkt_transmitted, *pkt_received,
-	    *pkt_loss;
+	    *pkt_success;
 	gchar stmp[128];
 
 	g_return_if_fail (netinfo != NULL);
@@ -221,7 +404,7 @@ ping_foreach_with_tree (Netinfo * netinfo, gchar * line, gint len,
 	max = GTK_LABEL (netinfo->max);
 	pkt_transmitted = GTK_LABEL (netinfo->packets_transmitted);
 	pkt_received = GTK_LABEL (netinfo->packets_received);
-	pkt_loss = GTK_LABEL (netinfo->packets_loss);
+	pkt_success = GTK_LABEL (netinfo->packets_success);
 
 	if (len > 0) {		/* there are data to show */
 		count = strip_line (line, &data, netinfo);
@@ -255,31 +438,25 @@ ping_foreach_with_tree (Netinfo * netinfo, gchar * line, gint len,
 				 data.srtt, data.unit);
 #endif /* DEBUG */
 
-			if (path != NULL) {
-				gtk_tree_model_get_iter (model, &sibling,
-							 path);
-				gtk_list_store_insert_after (GTK_LIST_STORE
-							     (model),
-							     &iter,
-							     &sibling);
-			} else {
-				gtk_list_store_append (GTK_LIST_STORE
-						       (model), &iter);
-			}
+			gtk_list_store_append (GTK_LIST_STORE
+					       (model), &iter);
 
 			gtk_list_store_set (GTK_LIST_STORE (model), &iter,
-					    0, data.bytes,
-					    1, data.ip,
-					    2, data.icmp_seq,
-					    3, data.srtt,
-					    4, data.unit, -1);
+					    BYTES_COLUMN, data.bytes,
+					    IP_COLUMN, data.ip,
+					    ICMP_SEQ_COLUMN, data.icmp_seq,
+					    SRTT_COLUMN, data.srtt,
+					    UNIT_COLUMN, data.unit, -1);
 
 			gtk_tree_view_set_model (GTK_TREE_VIEW (widget),
 						 model);
-			path = gtk_tree_model_get_path (model, &iter);
-			gtk_tree_view_set_cursor (GTK_TREE_VIEW (widget),
-						  path, NULL, FALSE);
-			gtk_tree_path_free (path);
+
+			if (path) {
+				gtk_tree_view_set_cursor (
+						GTK_TREE_VIEW (widget),
+						path, NULL, FALSE);
+				gtk_tree_path_free (path);
+			}
 
 			rtt = g_ascii_strtod (data.srtt, NULL);
 			rttmin = (rttmin > 0.0) ? MIN (rttmin, rtt) : rtt;
@@ -325,10 +502,9 @@ ping_foreach_with_tree (Netinfo * netinfo, gchar * line, gint len,
 		}
 
 		if (packets_transmitted == 0) {
-			packets_loss = 0;
+			packets_success = 0;
 		} else {
-			packets_loss =
-				100 -
+			packets_success =
 				((float) packets_received / packets_transmitted * 100);
 		}
 
@@ -336,9 +512,10 @@ ping_foreach_with_tree (Netinfo * netinfo, gchar * line, gint len,
 		gtk_label_set_text (pkt_transmitted, stmp);
 		g_sprintf (stmp, "%d", packets_received);
 		gtk_label_set_text (pkt_received, stmp);
-		g_sprintf (stmp, "%d%%", packets_loss);
-		gtk_label_set_text (pkt_loss, stmp);
+		g_sprintf (stmp, "%d%%", packets_success);
+		gtk_label_set_text (pkt_success, stmp);
 	}
+	draw_ping_graph (netinfo);
 }
 
 static gint
@@ -443,7 +620,7 @@ ping_copy_to_clipboard (Netinfo * netinfo, gpointer user_data)
 {
 	GString *result, *content;
 	const gchar *min, *avg, *max;
-	const gchar *pkt_transmitted, *pkt_received, *pkt_loss;
+	const gchar *pkt_transmitted, *pkt_received, *pkt_success;
 
 	g_return_if_fail (netinfo != NULL);
 
@@ -463,7 +640,7 @@ ping_copy_to_clipboard (Netinfo * netinfo, gpointer user_data)
 	    gtk_label_get_text (GTK_LABEL (netinfo->packets_transmitted));
 	pkt_received =
 	    gtk_label_get_text (GTK_LABEL (netinfo->packets_received));
-	pkt_loss = gtk_label_get_text (GTK_LABEL (netinfo->packets_loss));
+	pkt_success = gtk_label_get_text (GTK_LABEL (netinfo->packets_success));
 
 	/* The ping output in a text format (to copy on clipboard) */
 	g_string_append_printf (result, _("Time minimum:\t%s ms\n"), min);
@@ -474,7 +651,8 @@ ping_copy_to_clipboard (Netinfo * netinfo, gpointer user_data)
 				pkt_transmitted);
 	g_string_append_printf (result, _("Packets received:\t%s\n"),
 				pkt_received);
-	g_string_append_printf (result, _("Packet loss:\t%s\n"), pkt_loss);
+	g_string_append_printf (result, 
+	            _("Successful packets:\t%s\n"), pkt_success);
 
 	gtk_clipboard_set_text (gtk_clipboard_get (GDK_NONE), result->str,
 				result->len);
